@@ -17,8 +17,9 @@ def patch_init(mocker):
     """
     Makes patching a class' constructor slightly easier
     """
-    def patch_init(item, **kwargs):
-        mocker.patch.object(item, '__init__', return_value=None, **kwargs)
+    def patch_init(*args, **kwargs):
+        for item in args:
+            mocker.patch.object(item, '__init__', return_value=None, **kwargs)
     return patch_init
 
 
@@ -41,7 +42,10 @@ def patch_everything(mocker):
     def patch_everything(item, autospec=True, excludes=None, includes=None):
         for attribute in Utils.patchable_attributes(item, excludes=excludes,
                                                     includes=includes):
-            mocker.patch.object(item, attribute, autospec=autospec)
+            if attribute == '__init__':
+                mocker.patch.object(item, attribute, return_value=None)
+            else:
+                mocker.patch.object(item, attribute, autospec=autospec)
     return patch_everything
 
 
